
--[[                                     CurrencyMonitor

	This program watches a player's justice points, valor points, conquest points, and honor points
	and flashes an alert when any of them exceeds a predetermined threshold. Change the value on 
	line 59 to your desired threshold. CurrencyMonitor is meant to be super simple and configurable 
	only from within this file, meaning you won't find any slash commands or in-game configuration. 
	
	--- Version History ---
	
	12/2/2011 - V.0.1(BETA) Initial release.
	          - V.1.0       Now firing on the correct event  
	
	--- To-Do ---

	Give me some ideas if you like, but right now this does everything I expect it to do.
	
	--- Credits ---
	
	Credit goes to Wowhead user eidyia for the idea.

--]]

-- This is a table
currencies = {
	--[[ 
	Find these numbers on Wowhead. You can add your own here but for every instance of "4" below,
	you will need to change the 4 to the number of items in this list.
	--]]	
	
	"395", -- Justice points
	"396", -- Valor points
	"392", -- Honor points
	"390"  -- Conquest points
}

-- This is a table, too
currencyNames = {
	--[[ 
	Text strings for output. If you add a number to the table above, add the name of the currency in
	the same position right here. The number of items in this list must match the number of items in
	the above list.	Also be sure to change the 4s on lines 74, 96, and 107 to match the number of 
	items in the list. 
	--]]
	
	"Justice Points",
	"Valor Points",
	"Honor Points",
	"Conquest Points"
}

--[[
	Line 59 below holds the threshold at which you want CurrencyMonitor to alert you. After gaining
	a currency, for example Justice Points, if you have more than the value below this add-on will
	alert you with a faked raid warning. If you want the raid warning sound, simply remove the -- 
	from the beginning of line 114.
--]]

local maxAmount = 3000
-- Do not edit anything below this line. --

-- Empty table to be populated by the getCurrencies() function
currentAmount = {}

-- Register events. Makes the CurrencyMonitor_OnEvent() function fire when any of these occur.
function CurrencyMonitor_OnLoad()
	CurrencyMonitorFrame:RegisterEvent("CHAT_MSG_CURRENCY")
end

-- Insert current currency totals into the currentAmount table
function getCurrencies()
	
	-- Start a for loop that iterates 4 times
	for i = 1, 4 do
		
		--[[ Run the API's GetCurrencyInfo function, throw out the first returned value, and assign
			 the second returned value to the variable amountNow. The for loop checks each currency 
			 in the currencies table.
		--]]
		_, amountNow = GetCurrencyInfo(currencies[i])
		
		-- Insert the current value of amountNow into the currentAmount table as the index equal to
		-- the current value of i.
		table.insert(currentAmount,amountNow)
	end
end

-- Display the information to the user
function printOutput()
	
	-- Start a for loop then iterates 4 times
	for i = 1, 4 do
		
		-- Compare each value in the currentAmount table to see if it is greater than the threshold
		if currentAmount[i] > maxAmount then
			
			-- If the value is greater than the threshold, display the notice
			RaidNotice_AddMessage(RaidWarningFrame, "You have " .. currentAmount[i] .. " " .. currencyNames[i] .. "!", ChatTypeInfo["RAID_WARNING"])
		end
	end
end

-- The function to call every time either of the two registered events fires
function CurrencyMonitor_OnEvent(event, arg1)
	
	-- Start a for loop then iterate 4 times
	for i = 1, 4 do
	
	-- Define a variable as the type of currency that triggered "CHAT_MSG_CURRENCY"
	local trigger = string.match(arg1, currencyNames[i])
	
		-- Check the value of the variable and if it matches something in the table, run the functions
		if event == "CHAT_MSG_CURRENCY" and trigger == currencyNames[i] then
			--PlaySoundFile("Sound\\Interface\\RaidWarning.wav")
			getCurrencies()
			printOutput()
		end
	end
end